@@ -231,14 +231,14 @@ selection <- function(selection, outcome,
       ## extract the outcome formulas.  Anyone able to explain why do we need to do the complicated stuff?
       oArg <- match("outcome", names(mf), 0)
                                         # find the outcome argument
-      ocome <- as.list(mf[[oArg]])
-      formula1 <- ocome[[2]]
-      formula2 <- ocome[[3]]
+      # ocome <- as.list(mf[[oArg]])
+      # formula1 <- ocome[[2]]
+      # formula2 <- ocome[[3]]
                                         # If the formulas are not written explicitly but given as variables, 'formula*' are
                                         # the corresponding variable names and we have to extract the formulas in a different way:
-      if(!("formula" %in% class(formula1)))
+      # if(!("formula" %in% class(formula1)))
           formula1 <- outcome[[1]]
-      if(!("formula" %in% class(formula2)))
+      # if(!("formula" %in% class(formula2)))
           formula2 <- outcome[[2]]
                                         # Now we have extracted both formulas
       m <- match(c("outcome", "data", "subset", "weights",
